@@ -12,6 +12,7 @@ except:
 
 import logging
 
+from lib.core.common import getSafeExString
 from lib.core.data import conf
 from lib.core.data import logger
 from lib.core.exception import SqlmapConnectionException
@@ -43,7 +44,7 @@ class Connector(GenericConnector):
         try:
             self.connector = pyodbc.connect('Driver={Microsoft Access Driver (*.mdb)};Dbq=%s;Uid=Admin;Pwd=;' % self.db)
         except (pyodbc.Error, pyodbc.OperationalError), msg:
-            raise SqlmapConnectionException(msg[1])
+            raise SqlmapConnectionException(getSafeExString(msg))
 
         self.initCursor()
         self.printConnected()
@@ -52,16 +53,16 @@ class Connector(GenericConnector):
         try:
             return self.cursor.fetchall()
         except pyodbc.ProgrammingError, msg:
-            logger.log(logging.WARN if conf.dbmsHandler else logging.DEBUG, "(remote) %s" % msg[1])
+            logger.log(logging.WARN if conf.dbmsHandler else logging.DEBUG, "(remote) %s" % getSafeExString(msg))
             return None
 
     def execute(self, query):
         try:
             self.cursor.execute(query)
         except (pyodbc.OperationalError, pyodbc.ProgrammingError), msg:
-            logger.log(logging.WARN if conf.dbmsHandler else logging.DEBUG, "(remote) %s" % msg[1])
+            logger.log(logging.WARN if conf.dbmsHandler else logging.DEBUG, "(remote) %s" % getSafeExString(msg))
         except pyodbc.Error, msg:
-            raise SqlmapConnectionException(msg[1])
+            raise SqlmapConnectionException(getSafeExString(msg))
 
         self.connector.commit()
 
